Learn R Programming

statsDK (version 0.1.1)

retrieve_subjects: Retrieves an overview of the subjects from Statistics Denmark

Description

The function retrieves a data frame with the over all statistical subjects that can be pulled from Statistics Denmark.

Usage

retrieve_subjects(base_url = "http://api.statbank.dk/v1/")

Arguments

base_url

is the base url for the API you wish to call. Statistics Denmark can sometimes create custom API's that you can use by changing this parameter.

Value

a tibble

Examples

Run this code
# NOT RUN {
subjects <- statsDK::retrieve_subjects()
dplyr::glimpse(subjects)
# }

Run the code above in your browser using DataLab