powered by
The function retrieves a data frame with the over all statistical subjects that can be pulled from Statistics Denmark.
retrieve_subjects(base_url = "http://api.statbank.dk/v1/")
is the base url for the API you wish to call. Statistics Denmark can sometimes create custom API's that you can use by changing this parameter.
a tibble
# NOT RUN { subjects <- statsDK::retrieve_subjects() dplyr::glimpse(subjects) # }
Run the code above in your browser using DataLab